@@ -1,31 +1,27 @@
 package Tie::Array::Packed;
 
-our $VERSION = '0.12_02';
+use 5.008;
+
+our $VERSION = '0.01';
 
 use strict;
 use warnings;
-use Carp;
 
 require XSLoader;
 XSLoader::load('Tie::Array::Packed', $VERSION);
 
-my @short = qw(c C F f d i I j J s! S! l! L! n N v V q Q e E);
+my @short = qw(c C F f d i I i! I! s! S! l! L! n N v V);
 
 my %map = ( Char => 'c',
             UnsignedChar => 'C',
-            Hex => 'h',
             NV => 'F',
             Number => 'F',
             FloatNative => 'f',
             DoubleNative => 'd',
-            Integer => 'j',
-            UnsignedInteger => 'J',
-            IntegerPerl => 'j',
-            IV => 'j',
-            UnsignedIntegerPerl => 'J',
-            UV => 'J',
-            IntegerNative => 'i',
-            UnsignedIntegerNative => 'I',
+            Integer => 'i',
+            UnsignedInteger => 'I',
+            IntegerNative => 'i!',
+            UnsignedIntegerNative => 'I!',
             ShortNative => 's!',
             UnsignedShortNative => 'S!',
             LongNative => 'l!',
@@ -37,16 +33,7 @@ my %map = ( Char => 'c',
             UnsignedShortVax => 'v',
             UnsignedShortLE => 'v',
             UnsignedLongVax => 'V',
-            UnsignedLongLE => 'V',
-            Quad => 'q',
-            UnsignedQuad => 'Q',
-            LongLong => 'q',
-            UnsignedLongLong => 'Q',
-            Int64 => 'q',
-            UInt64 => 'Q',
-            Int128 => 'e',
-            UInt128 => 'E',
-          );
+            UnsignedLongLE => 'V' );
 
 
 @map{@short} = @short;
@@ -60,11 +47,8 @@ for my $name (keys %map) {
         sub {
             my $class = shift;
             my $self;
-            $self = TIEARRAY($class, $type, defined $_[0] ? $_[0] : '');
-            if (@_ > 1) {
-                shift;
-                $self->SPLICE(0, scalar(@_), @_);
-            }
+            $self = TIEARRAY($class, $type, @_ ? shift : '');
+            $self->SPLICE(0, scalar(@_), @_) if @_;
             $self;
         };
 }
@@ -81,71 +65,13 @@ sub make_with_packed {
     return \@self
 }
 
-sub make_clone {
-    my $self = shift;
-    tie my(@clone), ref($self), $$self;
-    return \@clone;
-}
+
 
 sub string {
     my $self = shift;
     $$self;
 }
 
-my $sort_packed_loaded;
-
-sub _load_sort_packed {
-    eval { require Sort::Packed };
-    croak __PACKAGE__ ."::sort requires package Sort::Packed"
-        if ($@ or !$Sort::Packed::VERSION);
-    $sort_packed_loaded++
-}
-
-sub sort {
-    @_ > 2 and croak 'Usage: tied(@parray)->sort([sub { CMP($a, $b) }])';
-    $sort_packed_loaded or _load_sort_packed;
-
-    my $self = shift;
-    my $packer = $self->packer;
-    if (@_) {
-        my $cmp = shift;
-        &Sort::Packed::sort_packed_custom($cmp, $packer, $$self);
-    }
-    else {
-        &Sort::Packed::sort_packed($packer, $$self);
-    }
-}
-
-
-sub shuffle {
-    @_ != 1 and croak 'Usage: tied(@parray)->shuffle';
-    $sort_packed_loaded or _load_sort_packed;
-
-    my $self = shift;
-    Sort::Packed::shuffle_packed($self->packer, $$self)
-}
-
-sub grep {
-    @_ != 2 and croak 'Usage: tied(@parray)->grep(sub { SELECT($_) })';
-
-    my $self = shift;
-    my $select = shift;
-
-    my $last = $self->FETCHSIZE - 1;
-    my $slow = 0;
-    for my $i (0..$last) {
-        for ($self->FETCH($i)) {
-            my $cp = $_;
-            if (&$select) {
-                $self->STORE($slow, $cp) if $slow < $i;
-                $slow++
-            }
-        }
-    }
-    $self->STORESIZE($slow);
-    $slow;
-}
-
 1;
 __END__
 
@@ -202,10 +128,10 @@ and are as follows:
   Tie::Array::Packed::Number                 F     NV
   Tie::Array::Packed::FloatNative            f     float
   Tie::Array::Packed::DoubleNative           d     double
-  Tie::Array::Packed::Integer                j     IV
-  Tie::Array::Packed::UnsignedInteger        J     UV
-  Tie::Array::Packed::IntegerNative          i     int
-  Tie::Array::Packed::UnsignedIntegerNative  I     unsigned int
+  Tie::Array::Packed::Integer                i     IV
+  Tie::Array::Packed::UnsignedInteger        I     UV
+  Tie::Array::Packed::IntegerNative          i!    int
+  Tie::Array::Packed::UnsignedIntegerNative  I!    unsigned int
   Tie::Array::Packed::ShortNative            s!    short
   Tie::Array::Packed::UnsignedShortNative    S!    unsigned short
   Tie::Array::Packed::LongNative             l!    long
@@ -219,34 +145,23 @@ and are as follows:
   Tie::Array::Packed::UnsignedLongVax        V     -
   Tie::Array::Packed::UnsignedLongLE         V     -
 
-If your Perl was compiled with 64bit support or the module
-L<Math::Int64> is installed, then the following two classes are also
-available:
+if your C compiler has support for 64bit long long integers, then this two
+classes will be also available:
 
-                                          pack      C
+                                           pack      C
             class name                    pattern   type
   --------------------------------------------------------------------
-  Tie::Array::Packed::Quad                   q     int64_t
-  Tie::Array::Packed::UnsignedQuad           Q     uint64_t
-
-If your C compiler supports 128bit integers and the module
-L<Math::Int128> is installed, then the following two classes are also
-available:
-
-                                          pack      C
-            class name                    pattern   type
-  --------------------------------------------------------------------
-  Tie::Array::Packed::Int128                 e     int128_t
-  Tie::Array::Packed::UInt128                E     uint128_t
+  Tie::Array::Packed::LongLong                q     long long
+  Tie::Array::Packed::UnsignedLongLong        Q     unsigned long long
 
 
-
-The tie interface for all these classes is as follows
-(Tie::Array::Packed::Integer is used as an example):
+The tie interface for those clases is:
 
   tie @foo, Tie::Array::Packed::Integer;
   tie @foo, Tie::Array::Packed::Integer, $init_string, @values
 
+(Tie::Array::Packed::Integer is used for example, the same applies to
+the rest of the classes).
 
 When a scalar value C<$init_string> is passed as an argument
 it is used as the initial value for the storage scalar.
@@ -283,61 +198,29 @@ class.
 
 Note that the returned array is not blessed into any package.
 
+
+
 =item Tie::Array::Packed::Integer->make_with_packed($init_string)
 
-=item Tie::Array::Packed::Integer->make_with_packed($init_string, @init_values)
+=itme Tie::Array::Packed::Integer->make_with_packed($init_string, @init_values)
 
-similar to the method before but gets an additional argument to
+similar to the method before but get an additional argument to
 initialize the storage scalar.
 
-=item tied(@array)->make_clone;
-
-returns a reference to a tied array that is a clone of C<@array>.
-
-Alternatively, to clone a tied array this idiom can be used:
-
-  my $tied = tied(@array);
-  tie my (@clone), ref($tied), $$tied;
-
-
 =item tied(@foo)->packer
 
 returns the pack template in use for the elements of the tied array
 C<@foo>.
 
-=item tied(@foo)->grep(sub { ...})
+=head1 BUGS
 
-in-place filter elements that comply with some condition.
+This is an early release, critical bugs may appear.
 
-=item tied(@foo)->reverse()
+Only tested on Linux, though it should work on any OS with a decent C
+compiler.
 
-reverses the order of the elements packed into the array
-
-=item tied(@foo)->rotate($places)
-
-=item tied(@foo)->sort()
-
-=item tied(@foo)->sort(sub { ...})
-
-=item tied(@foo)->shuffle
-
-See L<Sort::Packed> for the details about these methods.
-
-=back
-
-=head1 BUGS AND SUPPORT
-
-In order to report bugs you can send me and email to the address that
-appears below or use the CPAN RT bugtracking system available at
-L<http://rt.cpan.org>.
-
-The source for the development version of the module is hosted at
-GitHub: L<https://github.com/salva/p5-Tie-Array-Packed>.
-
-=head2 My wishlist
-
-If you like this module and you're feeling generous, take a look at my
-Amazon Wish List: L<http://amzn.com/w/1WU1P6IR5QZ42>
+To report bugs on this module email me to the address that appears
+below or use the CPAN RT system.
 
 =head1 SEE ALSO
 
@@ -346,22 +229,15 @@ Documentation for Perl builtins L<pack> and L<vec>.
 L<Tie::Array::PackedC> offers very similar functionality, but it is
 implemented in pure Perl and so it is slower.
 
-L<Tie::Array::Packed::Auto> is a wrapper module that loads
-Tie::Array::Packed when available, otherwise it uses
-Tie::Array::PackedC to provide an identical API.
-
 L<Array::Packed> is implemented in C but only supports integer values.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2008, 2011-2012 by Salvador FandiE<ntilde>o
-(sfandino@yahoo.com).
-
-Some parts copied from Tie::Array::PackedC (C) 2003-2006 by Yves
-Orton.
+Copyright (C) 2006 by Salvador FandiE<ntilde>o (sfandino@yahoo.com).
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
+
 =cut
